@@ -44,8 +44,10 @@ import logging
 import logging.handlers
 
 from gi import require_version # type: ignore
+# pylint: disable=wrong-import-position
 require_version('GLib', '2.0')
 from gi.repository import GLib # type: ignore
+# pylint: enable=wrong-import-position
 
 # set_prgname before importing other modules to show the name in warning
 # messages when import modules are failed. E.g. Gtk.
@@ -53,11 +55,13 @@ GLib.set_application_name('Emoji Picker')
 # This makes gnome-shell load the .desktop file when running under Wayland:
 GLib.set_prgname('emoji-picker')
 
+# pylint: disable=wrong-import-position
 require_version('Gdk', '3.0')
 from gi.repository import Gdk
 require_version('Gtk', '3.0')
 from gi.repository import Gtk
 from gi.repository import GObject
+# pylint: enable=wrong-import-position
 import itb_emoji
 import itb_util
 import itb_pango
@@ -157,9 +161,10 @@ def parse_args() -> Any:
         ('20200701', '13.0'),
         ('20200915', '13.1'),
         ('20210914', '14.0'),
+        ('20220913', '15.0'),
     )
     current_date = time.strftime('%Y%m%d')
-    current_unicode_version = '13.0'
+    current_unicode_version = '15.0'
     for (date, version) in unicode_versions:
         if current_date > date:
             current_unicode_version = version
@@ -607,8 +612,9 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
                  language, label_key, label])
         return True
 
-    def _sort_labels( # pylint: disable=no-self-use
-            self,
+    @classmethod
+    def _sort_labels(
+            cls,
             labels: Dict[str, List[str]],
             language: str) -> List[str]:
         return sorted(
@@ -882,7 +888,7 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             except (PermissionError, SyntaxError, IndentationError) as error:
                 LOGGER.exception('Error when reading options: %s: %s',
                                  error.__class__.__name__, error)
-            except Exception as error:
+            except Exception as error: # pylint: disable=broad-except
                 LOGGER.exception(
                     'Unexpected error when reading options: %s: %s',
                     error.__class__.__name__, error)
@@ -949,7 +955,7 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             except (PermissionError, SyntaxError, IndentationError) as error:
                 LOGGER.exception('Error reading recently used emoji: %s: %s',
                                  error.__class__.__name__, error)
-            except Exception as error:
+            except Exception as error: # pylint: disable=broad-except
                 LOGGER.exception(
                     'Unexpected error reading recently used emoji: %s: %s',
                     error.__class__.__name__, error)
@@ -1290,6 +1296,9 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             child.set_can_focus(False)
 
         self.show_all() # pylint: disable=no-member
+        if self._flowbox.get_children():
+            event_box = self._flowbox.get_children()[0].get_child()
+            self._emoji_event_box_selected(event_box, popover=False)
         self._candidates_invalid = False
         self._busy_stop()
 
@@ -1347,7 +1356,15 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             # If the text in the search entry changes while
             # the search bar is invisible, ignore it.
             return
-        self._query_string = query_string
+        if query_string.isspace():
+            # Keep it possible to search for space like characters when
+            # typing just white space:
+            self._query_string = query_string
+        else:
+            # If the query_string contains non-whitespace characters,
+            # strip it otherwise 'black cat ' would not be an exact match
+            # for 'black cat'.
+            self._query_string = query_string.strip()
         if self._candidates_invalid:
             if _ARGS.debug:
                 LOGGER.debug(
@@ -1440,7 +1457,8 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             self._emoji_selected_popover = None
         return False
 
-    def _emoji_event_box_selected(self, event_box: Gtk.EventBox) -> bool:
+    def _emoji_event_box_selected(
+            self, event_box: Gtk.EventBox, popover: bool = True) -> bool:
         '''
         Called when an event box containing an emoji
         was selected in the flowbox.
@@ -1466,6 +1484,8 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         self._show_concise_emoji_description_in_header_bar(emoji)
         self._set_clipboards(emoji)
         self._add_to_recently_used(emoji)
+        if not popover:
+            return True # Gdk.EVENT_PROPAGATE is defined as False
         self._emoji_selected_popover = Gtk.Popover()
         self._emoji_selected_popover.set_relative_to(event_box)
         self._emoji_selected_popover.set_position(Gtk.PositionType.TOP)
@@ -2207,6 +2227,7 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         if GTK_VERSION >= (3, 22, 0):
             self._font_popover.popup()
         self._font_popover.show_all()
+        font_popover_search_entry.grab_focus()
 
 def get_languages() -> List[str]:
     '''
